
import "Turbine";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Extensions";
import "Turbine.UI.Lotro";
import "Turbine.Debug";
import "DhorPlugins.Extensions";

MainWindow = class( Turbine.UI.Lotro.Window);

function MainWindow:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self );
	                
	-- load the player saved settings
	settings = { };
	settingsString = { };       -- save the settings as strings due to locale issue	
	self:LoadSettings();
	
	self:SetSize(400,600);
	self:SetPosition(settings.positionX,settings.positionY);
	self:SetVisible(true);
	self:SetText( mainTitleString );

   -- add toggle button   
   self.ToggleButton = DhorPlugins.MonsterItems.MPButton(self);
   self.ToggleButton:SetVisible(true);
   
   -- create a textbox to put the treeview into
   local textbox = Turbine.UI.Lotro.TextBox();
   textbox:SetSize(380,480);
   textbox:SetPosition(10,80);
   textbox:SetZOrder(0);
   textbox:SetParent(self);
   textbox:SetReadOnly(true);
   textbox:SetVisible(true);
   
   -- expand all button button
   expandAllButton = Turbine.UI.Lotro.Button();
   expandAllButton:SetSize(100,20);
   expandAllButton:SetPosition(95, 50);
   expandAllButton:SetText(expandAllString);
   expandAllButton:SetParent(self);
   expandAllButton:SetVisible(true);
   
   -- collapse all button
   collapseAllButton = Turbine.UI.Lotro.Button();
   collapseAllButton:SetSize(100,20);
   collapseAllButton:SetPosition(205, 50);
   collapseAllButton:SetText(collapseAllString);
   collapseAllButton:SetParent(self);
   collapseAllButton:SetVisible(true);   
   
         
   -- Create the tree view control.
   treeView = Turbine.UI.TreeView();
   treeView:SetParent( self );
   treeView:SetPosition( 10, 80 );
   treeView:SetSize( 380, 480 );
   treeView:SetBackColor( Turbine.UI.Color( 0.05, 0.05, 0.05 ) );
   treeView:SetIndentationWidth( 15 );
    
   -- Give the tree view a scroll bar.
   scriptTextScrollBar = Turbine.UI.Lotro.ScrollBar();
   scriptTextScrollBar:SetOrientation( Turbine.UI.Orientation.Vertical );
   scriptTextScrollBar:SetParent( self );
   scriptTextScrollBar:SetPosition( 380, 80 );
   scriptTextScrollBar:SetSize( 10, 480 );
    
   treeView:SetVerticalScrollBar( scriptTextScrollBar );
    
   itemCounts = { 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 };    
    
   self:AddNodes();
    
   player = Turbine.Gameplay.LocalPlayer.GetInstance();
   
      -- timers for events
	self.lastTime = 0;
   self.lastMove = 0;
   
   --[[ Event Handlers ]]--

	-- make sure we listen for updates
	self:SetWantsUpdates(true);
	self:SetWantsKeyEvents(true);
	
	-- check if our position has changed, and save the settings if so
	self.PositionChanged = function(sender, args )
		one,two = self:GetPosition();
		settings.positionX = one;
		settings.positionY = two;
		self:SaveSettings();
	end
   	
   -- check the items count once every 5 seconds
	-- or imediately on startup, but only if the
	-- window is visible
   	
	self.Update = function( sender,args)
		if(Turbine.Engine.GetGameTime() - self.lastTime > 5 
               and self:IsVisible() or self.lastTime == 0) then
			self.lastTime = Turbine.Engine.GetGameTime();
			self:CountItems();
			self:UpdateNodes();		
		end		
	end
    
   expandAllButton.MouseClick = function(sender,args)
      treeView:ExpandAll();
   end
      
   collapseAllButton.MouseClick = function(sender,args)
      treeView:CollapseAll();
   end
                  
	--Turbine.Shell.WriteLine("Main Got Here"); 	
   Plugins["MPItems"].Load = function(sender,args)
      Turbine.Shell.WriteLine("Monster Items version " .. Plugins["MPItems"]:GetVersion() .. " loaded");
      self:SetOpacity(1.0);
      self:SetVisible(false);
   end
end

function MainWindow:CountItems()
	-- get the player's inventory
	local i,j;
	backpack = player:GetBackpack();
	
	-- clear the counts
	for j = 1, table.getn(items),1 do
	   itemCounts[j] = 0;
	end
		
	for i = 1, backpack:GetSize(),1 do
		local item = backpack:GetItem(i);		
		
	   if(item ~= nil) then
		   for j = 1, table.getn(items),1 do
         
			   -- check the item matches
			   if(item:GetName() == items[j]) then
			      -- add the quantity to the total
				   itemCounts[j] = itemCounts[j] + item:GetQuantity();
			   end
		   end
		end
	end
end

function MainWindow:UpdateNodes()
   local i,j; 
   local nodeList = treeView:GetNodes();

   for i = 1, table.getn(CategoryStrings), 1 do
      local node = nodeList:Get(i);
      
      if(node ~= nil) then 
         local childNodes = node:GetChildNodes();       
      
         local counter = 1;
         for j = 1, table.getn(NeededCounts[i]), 1 do
            if(NeededCounts[i][j] ~= 0) then
               childLabel = childNodes:Get(counter):GetControls():Get(2);                              
               childLabel:SetText(itemCounts[j] .. "/" .. NeededCounts[i][j]);            
               counter = counter + 1;
            end                  
         end
      end 
   end
end    
       
function MainWindow:AddNodes()

       rootNodes = treeView:GetNodes();

       local i, j;
       
       for i = 1, table.getn(CategoryStrings), 1 do
          local node = Turbine.UI.TreeNode();
          
          local label = Turbine.UI.Label();
          label:SetSize(355,20);
          label:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft );
          label:SetText(CategoryStrings[i]);
          label:SetParent(node);
            
          label.MouseClick = function(sender,args)
             node:SetExpanded(node:IsExpanded() == true);
          end
          
          label.MouseEnter = function(sender,args)
             label:SetBackColor( Turbine.UI.Color( 0.55, 0.15, 0.15 ));
          end
          
          label.MouseLeave = function(sender,args)
             label:SetBackColor( Turbine.UI.Color( 0.05, 0.05, 0.05 ));          
          end        
          
          node:SetSize(380,20);
          node:SetExpanded(false);
    	    rootNodes:Add( node );
    	    
          local subNodes = node:GetChildNodes();           
          
          for j = 1, table.getn(NeededCounts[i]), 1 do
                    
             if(NeededCounts[i][j] ~= 0) then
                local node = Turbine.UI.TreeNode();
             
                local label = Turbine.UI.Label();
                label:SetSize(290,20);
                label:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft );
                label:SetText(items[j]);
                label:SetZOrder(10);
                label:SetParent(node);                
                             
                local label2 = Turbine.UI.Label();
                label2:SetSize(50,20);
                label2:SetPosition(290,0);
                label2:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleRight );
                label2:SetText(itemCounts[j] .. "/" .. NeededCounts[i][j]); 
                label2:SetZOrder(9);
                label2:SetParent(node);
                          
                label.MouseEnter = function(sender,args)
                  label:SetBackColor( Turbine.UI.Color( 0.15, 0.15, 0.55 ));
                  label2:SetBackColor( Turbine.UI.Color( 0.15, 0.15, 0.55 ));
                end
          
                label.MouseLeave = function(sender,args)
                  label:SetBackColor( Turbine.UI.Color( 0.05, 0.05, 0.05 ));
                  label2:SetBackColor( Turbine.UI.Color( 0.05, 0.05, 0.05 ));          
                end
                
                label2.MouseEnter = function(sender,args)
                  label:SetBackColor( Turbine.UI.Color( 0.15, 0.15, 0.55 ));
                  label2:SetBackColor( Turbine.UI.Color( 0.15, 0.15, 0.55 ));
                end
          
                label2.MouseLeave = function(sender,args)
                  label:SetBackColor( Turbine.UI.Color( 0.05, 0.05, 0.05 ));
                  label2:SetBackColor( Turbine.UI.Color( 0.05, 0.05, 0.05 ));          
                end  
                           
                node:SetSize(380,20);
                node:SetExpanded(false);
    	          subNodes:Add( node );                  
             end
          end               
       end
end

function MainWindow:LoadSettings()
	-- load the self.settings.  If a value is not available, set a default value
	
   settings = { };
   
   pcall(function()	
	   settingsString = Turbine.PluginData.Load( Turbine.DataScope.Character, 
                                                "MPItemsSettings" );
   end);
 
	if ( type( settingsString ) ~= "table" ) then
		settingsString = { };
	end
	
	if ( not settingsString.positionX ) then
		settingsString.positionX = tostring(Turbine.UI.Display.GetWidth()
                                           - self:GetWidth() - 50); 
	end

	if ( not settingsString.positionY ) then
		settingsString.positionY = tostring(Turbine.UI.Display.GetHeight()
                                              - self:GetHeight() - 50 * 1.5);
	end
	
	if ( not settingsString.buttonPositionX ) then
		settingsString.buttonPositionX = tostring(Turbine.UI.Display.GetWidth()
                                           - self:GetWidth() - 50); 
	end

	if ( not settingsString.buttonPositionY ) then
		settingsString.buttonPositionY = tostring(Turbine.UI.Display.GetHeight()
                                              - self:GetHeight() - 50 * 1.5);
	end
	                                      	
   -- convert from strings if necessary
      if(type( settingsString.positionX ) == "string" ) then
	   settings.positionX = tonumber(settingsString.positionX);
	else
	   settings.positionX = settingsString.positionX;
   end
   
   if(type( settingsString.positionY ) == "string" ) then
	   settings.positionY = tonumber(settingsString.positionY);
	else
	   settings.positionY = settingsString.positionY;
   end
     
   if(type( settingsString.buttonPositionX ) == "string" ) then
	   settings.buttonPositionX = tonumber(settingsString.buttonPositionX);
	else
	   settings.buttonPositionX = settingsString.buttonPositionX;
   end
   
   if(type( settingsString.positionY ) == "string" ) then
	   settings.buttonPositionY = tonumber(settingsString.buttonPositionY);
	else
	   settings.buttonPositionY = settingsString.buttonPositionY;
   end 
end
  
function MainWindow:SaveSettings()
   
	   -- convert the settings to strings 
		settingsString.positionX = tostring(settings.positionX);
		settingsString.positionY = tostring(settings.positionY);
		settingsString.buttonPositionX = tostring(settings.buttonPositionX);
		settingsString.buttonPositionY = tostring(settings.buttonPositionY);
      
      	-- save the settings
	Turbine.PluginData.Save( Turbine.DataScope.Character,
                                  "MPItemsSettings", settingsString ); 
end
